@@ -1,6 +1,6 @@
 ﻿/*
 Technitium DNS Server
-Copyright (C) 2023  Shreyas Zare (shreyas@technitium.com)
+Copyright (C) 2025  Shreyas Zare (shreyas@technitium.com)
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ function refreshApps() {
     divViewAppsLoader.show();
 
     HTTPRequest({
-        url: "/api/apps/list?token=" + sessionData.token,
+        url: "api/apps/list?token=" + sessionData.token,
         success: function (responseJSON) {
             var apps = responseJSON.response.apps;
             var tableHtmlRows = "";
@@ -86,11 +86,14 @@ function getAppRowHtml(app) {
 
             if (app.dnsApps[j].isAuthoritativeRequestHandler)
                 labels += "<span class=\"label label-info\" style=\"margin-right: 4px;\">Authoritative</span>";
-                
+
             if (app.dnsApps[j].isRequestBlockingHandler)
                 labels += "<span class=\"label label-info\" style=\"margin-right: 4px;\">Blocking</span>";
 
             if (app.dnsApps[j].isQueryLogger)
+                labels += "<span class=\"label label-info\" style=\"margin-right: 4px;\">Query Logger</span>";
+
+            if (app.dnsApps[j].isQueryLogs)
                 labels += "<span class=\"label label-info\" style=\"margin-right: 4px;\">Query Logs</span>";
 
             if (app.dnsApps[j].isPostProcessor)
@@ -140,7 +143,7 @@ function showStoreAppsModal() {
     $("#modalStoreApps").modal("show");
 
     HTTPRequest({
-        url: "/api/apps/listStoreApps?token=" + sessionData.token,
+        url: "api/apps/listStoreApps?token=" + sessionData.token,
         success: function (responseJSON) {
             var storeApps = responseJSON.response.storeApps;
             var tableHtmlRows = "";
@@ -219,7 +222,7 @@ function installStoreApp(objBtn, appName, url) {
     btn.button('loading');
 
     HTTPRequest({
-        url: "/api/apps/downloadAndInstall?token=" + sessionData.token + "&name=" + encodeURIComponent(appName) + "&url=" + encodeURIComponent(url),
+        url: "api/apps/downloadAndInstall?token=" + sessionData.token + "&name=" + encodeURIComponent(appName) + "&url=" + encodeURIComponent(url),
         success: function (responseJSON) {
             btn.button('reset');
             btn.hide();
@@ -255,7 +258,7 @@ function updateStoreApp(objBtn, appName, url, isModal) {
     btn.button('loading');
 
     HTTPRequest({
-        url: "/api/apps/downloadAndUpdate?token=" + sessionData.token + "&name=" + encodeURIComponent(appName) + "&url=" + encodeURIComponent(url),
+        url: "api/apps/downloadAndUpdate?token=" + sessionData.token + "&name=" + encodeURIComponent(appName) + "&url=" + encodeURIComponent(url),
         success: function (responseJSON) {
             btn.button('reset');
             btn.hide();
@@ -293,7 +296,7 @@ function uninstallStoreApp(objBtn, appName) {
     btn.button('loading');
 
     HTTPRequest({
-        url: "/api/apps/uninstall?token=" + sessionData.token + "&name=" + encodeURIComponent(appName),
+        url: "api/apps/uninstall?token=" + sessionData.token + "&name=" + encodeURIComponent(appName),
         success: function (responseJSON) {
             btn.button('reset');
             btn.hide();
@@ -344,7 +347,7 @@ function installApp() {
     var btn = $("#btnInstallApp").button('loading');
 
     HTTPRequest({
-        url: "/api/apps/install?token=" + sessionData.token + "&name=" + encodeURIComponent(appName),
+        url: "api/apps/install?token=" + sessionData.token + "&name=" + encodeURIComponent(appName),
         method: "POST",
         data: formData,
         contentType: false,
@@ -386,7 +389,7 @@ function updateApp() {
     var btn = $("#btnUpdateApp").button('loading');
 
     HTTPRequest({
-        url: "/api/apps/update?token=" + sessionData.token + "&name=" + encodeURIComponent(appName),
+        url: "api/apps/update?token=" + sessionData.token + "&name=" + encodeURIComponent(appName),
         method: "POST",
         data: formData,
         contentType: false,
@@ -419,7 +422,7 @@ function uninstallApp(objBtn, appName) {
     btn.button('loading');
 
     HTTPRequest({
-        url: "/api/apps/uninstall?token=" + sessionData.token + "&name=" + encodeURIComponent(appName),
+        url: "api/apps/uninstall?token=" + sessionData.token + "&name=" + encodeURIComponent(appName),
         success: function (responseJSON) {
             var id = btn.attr("data-id");
             $("#trApp" + id).remove();
@@ -450,7 +453,7 @@ function showAppConfigModal(objBtn, appName) {
     btn.button('loading');
 
     HTTPRequest({
-        url: "/api/apps/config/get?token=" + sessionData.token + "&name=" + encodeURIComponent(appName),
+        url: "api/apps/config/get?token=" + sessionData.token + "&name=" + encodeURIComponent(appName),
         success: function (responseJSON) {
             btn.button('reset');
 
@@ -485,7 +488,7 @@ function saveAppConfig() {
     var btn = $("#btnAppConfig").button("loading");
 
     HTTPRequest({
-        url: "/api/apps/config/set?token=" + sessionData.token + "&name=" + encodeURIComponent(appName),
+        url: "api/apps/config/set?token=" + sessionData.token + "&name=" + encodeURIComponent(appName),
         method: "POST",
         data: "config=" + encodeURIComponent(config),
         processData: false,
